@@ -9,14 +9,13 @@
 #define KIO_SKIPDIALOG_H
 
 #include "kiowidgets_export.h"
-#include <kio/jobuidelegateextension.h>
 #include <QDialog>
+#include <kio/jobuidelegateextension.h>
 
 class QWidget;
 
 namespace KIO
 {
-
 class SkipDialogPrivate;
 /**
  * @internal
@@ -42,7 +41,7 @@ Q_SIGNALS:
      * @deprecated since 5.79, Use QDialog::finished(int result)
      */
     KIOWIDGETS_DEPRECATED_VERSION(5, 79, "Use QDialog::finished(int result)")
-    void result(SkipDialog *_this, int _button); // clazy:exclude=fully-qualified-moc-types
+    void result(SkipDialog *_this, int _button); // clazy:exclude=fully-qualified-moc-types,overloaded-signal
 #endif
 
 private:
